@@ -18,7 +18,7 @@ use Wx 0.9908;
 use Wx::Print;
 use Cwd;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 our $_binpath;
 our $_libpath;
@@ -116,28 +116,28 @@ sub ShowFont { Wx::PdfDocument::_utilscmd(qq($_binpath/showfont), $_[0]); }
 
 no strict;
 
-package Wx::PdfLayerGroup;
-package Wx::PdfOcg;
-package Wx::PdfColour;
-package Wx::PdfInfo;
-package Wx::PdfLineStyle;
-package Wx::PdfShape;
-package Wx::PdfFont;
-package Wx::PdfFontDescription;
-package Wx::PdfFontManager;
-package Wx::PdfBarCodeCreator;
-package Wx::PdfLayer;             @ISA = qw( Wx::PdfOcg );
-package Wx::PdfLayerMembership;   @ISA = qw( Wx::PdfOcg );
-package Wx::PdfDC;                @ISA = qw( Wx::DC );
-package Wx::PdfLink;
-package Wx::PdfPageLink;          @ISA = qw( Wx::PdfLink );
-package Wx::PdfPrinter;           @ISA = qw( Wx::Printer );
-package Wx::PdfPrintData;         @ISA = qw( Wx::Object );
-package Wx::PdfPrintPreview;      @ISA = qw( Wx::PrintPreview );
-package Wx::PdfPrintPreviewImpl;  @ISA = qw( Wx::PrintPreview );
-package Wx::PdfPageSetupDialog;   @ISA = qw( Wx::Dialog );
-package Wx::PdfPrintDialog;       @ISA = qw( Wx::PrintDialog );
-package Wx::PlPdfDocument;        @ISA = qw( Wx::PdfDocument );
+package Wx::PdfLayerGroup; $VERSION = '0.01';
+package Wx::PdfOcg; $VERSION = '0.01';
+package Wx::PdfColour; $VERSION = '0.01';
+package Wx::PdfInfo; $VERSION = '0.01';
+package Wx::PdfLineStyle; $VERSION = '0.01';
+package Wx::PdfShape; $VERSION = '0.01';
+package Wx::PdfFont; $VERSION = '0.01';
+package Wx::PdfFontDescription; $VERSION = '0.01';
+package Wx::PdfFontManager; $VERSION = '0.01';
+package Wx::PdfBarCodeCreator; $VERSION = '0.01';
+package Wx::PdfLayer; $VERSION = '0.01';             @ISA = qw( Wx::PdfOcg );
+package Wx::PdfLayerMembership; $VERSION = '0.01';   @ISA = qw( Wx::PdfOcg );
+package Wx::PdfDC; $VERSION = '0.01';                @ISA = qw( Wx::DC );
+package Wx::PdfLink; $VERSION = '0.01';
+package Wx::PdfPageLink; $VERSION = '0.01';          @ISA = qw( Wx::PdfLink );
+package Wx::PdfPrinter; $VERSION = '0.01';           @ISA = qw( Wx::Printer );
+package Wx::PdfPrintData; $VERSION = '0.01';         @ISA = qw( Wx::Object );
+package Wx::PdfPrintPreview; $VERSION = '0.01';      @ISA = qw( Wx::PrintPreview );
+package Wx::PdfPrintPreviewImpl; $VERSION = '0.01';  @ISA = qw( Wx::PrintPreview );
+package Wx::PdfPageSetupDialog; $VERSION = '0.01';   @ISA = qw( Wx::Dialog );
+package Wx::PdfPrintDialog; $VERSION = '0.01';       @ISA = qw( Wx::PrintDialog );
+package Wx::PlPdfDocument; $VERSION = '0.01';        @ISA = qw( Wx::PdfDocument );
 
 1;
 
